SWDEV-470698 - fix formatting, add format check workflow (#657)
이 커밋은 다음에 포함됨:
@@ -20,18 +20,17 @@ THE SOFTWARE.
|
||||
constexpr int GLOBAL_BUF_SIZE = 2048;
|
||||
|
||||
__device__ float deviceGlobalFloat;
|
||||
__device__ int deviceGlobalInt1;
|
||||
__device__ int deviceGlobalInt2;
|
||||
__device__ short deviceGlobalShort; //NOLINT
|
||||
__device__ char deviceGlobalChar;
|
||||
__device__ int deviceGlobalInt1;
|
||||
__device__ int deviceGlobalInt2;
|
||||
__device__ short deviceGlobalShort; // NOLINT
|
||||
__device__ char deviceGlobalChar;
|
||||
|
||||
__device__ int getSquareOfGlobalFloat() {
|
||||
return static_cast<int>(deviceGlobalFloat*deviceGlobalFloat);
|
||||
return static_cast<int>(deviceGlobalFloat * deviceGlobalFloat);
|
||||
}
|
||||
|
||||
extern "C" __global__ void testWeightedCopy(int* a, int* b) {
|
||||
int tx = threadIdx.x;
|
||||
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 +
|
||||
static_cast<int>(deviceGlobalShort) + static_cast<int>(deviceGlobalChar)
|
||||
+ getSquareOfGlobalFloat();
|
||||
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 + static_cast<int>(deviceGlobalShort) +
|
||||
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
|
||||
}
|
||||
|
||||
새 이슈에서 참조
사용자 차단